==> mkvtoolnix_90.0.orig.tar.xz: mkvtoolnix-90.0/packaging/macos/specs.sh <==
spec_autoconf=(autoconf-2.69.tar.xz https://ftp.gnu.org/gnu/autoconf/autoconf-2.69.tar.xz 64ebcec9f8ac5b2487125a86a7760d2591ac9e1d3dbd59489633f9de62a57684)
spec_automake=(automake-1.16.1.tar.gz https://ftp.gnu.org/gnu/automake/automake-1.16.1.tar.xz 5d05bb38a23fd3312b10aea93840feec685bdf4a41146e78882848165d3ae921)
spec_boost=(boost_1_85_0.tar.bz2 https://boostorg.jfrog.io/artifactory/main/release/1.85.0/source/boost_1_85_0.tar.bz2 7009fe1faa1697476bdc7027703a2badb84e849b7b0baad5086b087b971f8617)
spec_cmake=(cmake-3.31.3.tar.gz https://cmake.org/files/v3.31/cmake-3.31.3.tar.gz fac45bc6d410b49b3113ab866074888d6c9e9dc81a141874446eb239ac38cb87)
spec_cmark=(cmark-0.30.3.tar.gz https://github.com/commonmark/cmark/archive/0.30.3.tar.gz 85e9fb515531cc2c9ae176d693f9871774830cf1f323a6758fb187a5148d7b16)
spec_curl=(curl-8.11.1.tar.xz https://curl.se/download/curl-8.11.1.tar.xz c7ca7db48b0909743eaef34250da02c19bc61d4f1dcedd6603f109409536ab56)
spec_flac=(flac-1.4.3.tar.xz http://downloads.xiph.org/releases/flac/flac-1.4.3.tar.xz 6c58e69cd22348f441b861092b825e591d0b822e106de6eb0ee4d05d27205b70)
spec_gettext=(gettext-0.23.tar.lz https://ftp.gnu.org/gnu/gettext/gettext-0.23.tar.lz 9878994930a8e09f1e3186203b3ff2accb2c4e67ddc6098b2c1e4a74364d3c5a)
spec_gmp=(gmp-6.3.0.tar.xz https://gmplib.org/download/gmp/gmp-6.3.0.tar.xz a3c2b80201b89e68616f4ad30bc66aee4927c3ce50e33929ca819d5c43538898)
spec_libiconv=(libiconv-1.16.tar.gz https://ftp.gnu.org/gnu/libiconv/libiconv-1.16.tar.gz e6a1b1b589654277ee790cce3734f07876ac4ccfaecbee8afa0b649cf529cc04)
spec_ogg=(libogg-1.3.4.tar.xz http://downloads.xiph.org/releases/ogg/libogg-1.3.4.tar.xz c163bc12bc300c401b6aa35907ac682671ea376f13ae0969a220f7ddf71893fe)
spec_pkgconfig=(pkg-config-0.29.2.tar.gz https://pkg-config.freedesktop.org/releases/pkg-config-0.29.2.tar.gz 6fc69c01688c9458a57eb9a1664c9aba372ccda420a02bf4429fe610e7e7d591)
spec_vorbis=(libvorbis-1.3.7.tar.xz http://downloads.xiph.org/releases/vorbis/libvorbis-1.3.7.tar.xz b33cc4934322bcbf6efcbacf49e3ca01aadbea4114ec9589d1b1e9d20f72954b)
spec_zlib=(zlib-v1.3.1.tar.xz https://www.zlib.net/zlib-v1.3.1.tar.xz 38ef96b8dfe510d42707d9c781877914792541133e1870841463bfa73f883e32)

spec_qt=(qt-everywhere-src-6.8.1.tar.xz https://download.qt.io/official_releases/qt/6.8/6.8.1/single/qt-everywhere-src-6.8.1.tar.xz 45e3a9f6d33c92ffe65a1fde1a8eba5b228112df675f7f9026eaa332b2e2edff)

==> mkvtoolnix-93.0.tar.xz: mkvtoolnix-93.0/packaging/macos/specs.sh <==
spec_autoconf=(autoconf-2.69.tar.xz https://ftp.gnu.org/gnu/autoconf/autoconf-2.69.tar.xz 64ebcec9f8ac5b2487125a86a7760d2591ac9e1d3dbd59489633f9de62a57684)
spec_automake=(automake-1.16.1.tar.gz https://ftp.gnu.org/gnu/automake/automake-1.16.1.tar.xz 5d05bb38a23fd3312b10aea93840feec685bdf4a41146e78882848165d3ae921)
spec_boost=(boost_1_85_0.tar.bz2 https://boostorg.jfrog.io/artifactory/main/release/1.85.0/source/boost_1_85_0.tar.bz2 7009fe1faa1697476bdc7027703a2badb84e849b7b0baad5086b087b971f8617)
spec_cmake=(cmake-3.31.3.tar.gz https://cmake.org/files/v3.31/cmake-3.31.3.tar.gz fac45bc6d410b49b3113ab866074888d6c9e9dc81a141874446eb239ac38cb87)
spec_cmark=(cmark-0.30.3.tar.gz https://github.com/commonmark/cmark/archive/0.30.3.tar.gz 85e9fb515531cc2c9ae176d693f9871774830cf1f323a6758fb187a5148d7b16)
spec_curl=(curl-8.11.1.tar.xz https://curl.se/download/curl-8.11.1.tar.xz c7ca7db48b0909743eaef34250da02c19bc61d4f1dcedd6603f109409536ab56)
spec_docbook_xsl=(docbook-xsl-1.79.2.tar.gz https://github.com/docbook/xslt10-stylesheets/releases/download/release%2F1.79.2/docbook-xsl-1.79.2.tar.gz 966188d7c05fc76eaca115a55893e643dd01a3486f6368733c9ad974fcee7a26)
spec_flac=(flac-1.4.3.tar.xz http://downloads.xiph.org/releases/flac/flac-1.4.3.tar.xz 6c58e69cd22348f441b861092b825e591d0b822e106de6eb0ee4d05d27205b70)
spec_gettext=(gettext-0.23.tar.lz https://ftp.gnu.org/gnu/gettext/gettext-0.23.tar.lz 9878994930a8e09f1e3186203b3ff2accb2c4e67ddc6098b2c1e4a74364d3c5a)
spec_gmp=(gmp-6.3.0.tar.xz https://gmplib.org/download/gmp/gmp-6.3.0.tar.xz a3c2b80201b89e68616f4ad30bc66aee4927c3ce50e33929ca819d5c43538898)
spec_libiconv=(libiconv-1.16.tar.gz https://ftp.gnu.org/gnu/libiconv/libiconv-1.16.tar.gz e6a1b1b589654277ee790cce3734f07876ac4ccfaecbee8afa0b649cf529cc04)
spec_ogg=(libogg-1.3.4.tar.xz http://downloads.xiph.org/releases/ogg/libogg-1.3.4.tar.xz c163bc12bc300c401b6aa35907ac682671ea376f13ae0969a220f7ddf71893fe)
spec_pkgconfig=(pkg-config-0.29.2.tar.gz https://pkg-config.freedesktop.org/releases/pkg-config-0.29.2.tar.gz 6fc69c01688c9458a57eb9a1664c9aba372ccda420a02bf4429fe610e7e7d591)
spec_vorbis=(libvorbis-1.3.7.tar.xz http://downloads.xiph.org/releases/vorbis/libvorbis-1.3.7.tar.xz b33cc4934322bcbf6efcbacf49e3ca01aadbea4114ec9589d1b1e9d20f72954b)
spec_zlib=(zlib-v1.3.1.tar.xz https://www.zlib.net/zlib-v1.3.1.tar.xz 38ef96b8dfe510d42707d9c781877914792541133e1870841463bfa73f883e32)

spec_qt=(qt-everywhere-src-6.8.1.tar.xz https://download.qt.io/official_releases/qt/6.8/6.8.1/single/qt-everywhere-src-6.8.1.tar.xz 45e3a9f6d33c92ffe65a1fde1a8eba5b228112df675f7f9026eaa332b2e2edff)
